@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-03-28'; # DATE
+our $DATE = '2023-03-29'; # DATE
 our $DIST = 'Parse-FireDiamond'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use Exporter qw(import);
 our @EXPORT_OK = qw(
@@ -59,8 +59,7 @@ our %fire_hazard_attrs = (
     },
     1 => {
         meaning => "above 93 °C",
-        meaning=>"slightly hazardous",
-        explanation => "",
+        explanation => "Materials that require considerable preheating, under all ambient temperature conditions, before ignition and combustion can occur (e.g. mineral oil, ammonia, ethylene glycol). Includes some finely divided suspended solids that do not require heating before ignition can occur. Flash point at or above 93.3 °C (200 °F).",
     },
     0 => {
         meaning=>"not flammable",
@@ -248,7 +247,7 @@ Parse::FireDiamond - Parse Fire Diamond (NFPA 704) notation
 
 =head1 VERSION
 
-This document describes version 0.003 of Parse::FireDiamond (from Perl distribution Parse-FireDiamond), released on 2023-03-28.
+This document describes version 0.004 of Parse::FireDiamond (from Perl distribution Parse-FireDiamond), released on 2023-03-29.
 
 =head1 SYNOPSIS
 
@@ -287,7 +286,7 @@ Result:
    200,
    "OK (parsed)",
    {
-     fire_hazard_meaning   => "slightly hazardous",
+     fire_hazard_meaning   => "above 93 \xC2\xB0C",
      fire_hazard_number    => 1,
      health_hazard_meaning => "hazardous",
      health_hazard_number  => 2,
@@ -295,7 +294,7 @@ Result:
      reactivity_number     => 0,
    },
    {
-     "func.fire_hazard_explanation"   => "",
+     "func.fire_hazard_explanation"   => "Materials that require considerable preheating, under all ambient temperature conditions, before ignition and combustion can occur (e.g. mineral oil, ammonia, ethylene glycol). Includes some finely divided suspended solids that do not require heating before ignition can occur. Flash point at or above 93.3 \xC2\xB0C (200 \xC2\xB0F).",
      "func.health_hazard_explanation" => "Intense or continued but not chronic exposure could cause temporary incapacitation or possible residual injury (e.g. diethyl ether, ammonium phosphate, carbon dioxide, chloroform, DEET).",
      "func.reactivity_explanation"    => "Normally stable, even under fire exposure conditions, and is not reactive with water (e.g. helium, N2, carbon dioxide)",
    },
@@ -311,7 +310,7 @@ Result:
    200,
    "OK (parsed)",
    {
-     fire_hazard_meaning   => "slightly hazardous",
+     fire_hazard_meaning   => "above 93 \xC2\xB0C",
      fire_hazard_number    => 1,
      health_hazard_meaning => "normal material",
      health_hazard_number  => 0,
@@ -319,7 +318,7 @@ Result:
      reactivity_number     => 0,
    },
    {
-     "func.fire_hazard_explanation"   => "",
+     "func.fire_hazard_explanation"   => "Materials that require considerable preheating, under all ambient temperature conditions, before ignition and combustion can occur (e.g. mineral oil, ammonia, ethylene glycol). Includes some finely divided suspended solids that do not require heating before ignition can occur. Flash point at or above 93.3 \xC2\xB0C (200 \xC2\xB0F).",
      "func.health_hazard_explanation" => "Poses no health hazard, no precautions necessary and would offer no hazard beyond that of ordinary combustible materials (e.g. wood, sugar, salt, propylene glycol)",
      "func.reactivity_explanation"    => "Normally stable, even under fire exposure conditions, and is not reactive with water (e.g. helium, N2, carbon dioxide)",
    },
